@@ -1,10 +1,15 @@
-#include <iostream.h>
+#include "ex.h"
 #include <signal.h>
 #include <math.h>
 #include <setjmp.h>
 #include <qpthr/qp.h>
 #include <qpthr/qp_work.h>
 
+// XJB - signals are not supported on Windows
+#ifdef WIN32
+#error "Signals are not supported on Windows!"
+#endif // WIN32
+
 int sigtest_run = 1;
 
 void sig_term_func(int sig, void *arg)
@@ -20,7 +25,7 @@ void sig_fpe_func()
 
 void sig_segv_handler(int sig, void *arg)
 {
-	printf("segm. fault (*(NULL) = 1)\n");
+	printf("segm. fault (*dp = 1)\n");
 	sigjmp_buf *buf = (sigjmp_buf *) arg;
 	siglongjmp(*buf, 1);
 }
@@ -65,8 +70,9 @@ class SigTest: public QpThread {
 
 int main()
 {
+	cout << "init" << endl;
 	QpInit qp_init(QpInit::QP_SIGNAL);
-
+	cout << "init done" << endl;
 	cout << "Main " << QpThread::CurrentSeq() << " pid " << getpid() << endl;
 	QpSignal::InstallHandler(SIGTERM, QpSignal::HANDLER);
  	QpSignal::InstallHandler(SIGFPE,  QpSignal::HANDLER);
